#!/usr/bin/env python
# -*- encoding: utf-8 -*-
#
# Authors: Alejandro J. Cura <alecu@canonical.com>
#
# Copyright (C) 2010 Canonical Ltd.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#


import gobject

import dbus
import dbus.service
import dbus.mainloop.glib

import sys

OBJECT_PATH = "/"
OBJECT_NAME = "com.ubuntuone.SyncDaemon"
OBJECT_INTERFACE = "com.ubuntuone.SyncDaemon.SyncDaemon"
SAMPLE_VOLUME_INFO = {
    "volume_id": "sample_volume_id",
    "owner_id": "sample_owner_id",
    "volume_name": "sample_volume_name",
    "type": "UDF",
}
SAMPLE_SHARE_INFO = {
    "volume_id": "other_volume_id",
    "owner_id": "other_owner_id",
    "volume_name": "other_volume_name",
    "type": "Share",
    "other_visible_name": "Other User",
    "path": "~/A shared folder",
}

class SyncDaemonMocker(dbus.service.Object):
    def __init__(self, conn, object_path=OBJECT_PATH):
        dbus.service.Object.__init__(self, conn, object_path)

    @dbus.service.signal(OBJECT_INTERFACE)
    def QuotaExceeded(self, volume_info):
        pass

    @dbus.service.method(OBJECT_INTERFACE)
    def emitQuotaExceeded(self):
        self.QuotaExceeded(SAMPLE_VOLUME_INFO)
        return 'Signal emitted'

    @dbus.service.method(OBJECT_INTERFACE, in_signature='', out_signature='')
    def Quit(self):
        main_loop.quit()

if __name__ == '__main__':
    dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)

    bus = dbus.SessionBus()
    name = dbus.service.BusName(OBJECT_NAME, bus)
    object = SyncDaemonMocker(bus)

    main_loop = gobject.MainLoop()

    if "-d" not in sys.argv:
        if "-3" in sys.argv:
            gobject.timeout_add(10, object.QuotaExceeded, SAMPLE_SHARE_INFO)
        else:
            gobject.timeout_add(10, object.QuotaExceeded, SAMPLE_VOLUME_INFO)
        gobject.timeout_add(200, main_loop.quit)

    main_loop.run()
