# ubuntuone.platform.linux - linux platform imports
#
# Author: Lucio Torre <lucio.torre@canonical.com>
#
# Copyright 2009 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Linux import for ubuntuone-client

This module has to have all linux specific modules and provide the api required
to support the linux platform."""

platform = "linux2"

import dbus
from dbus.mainloop.glib import DBusGMainLoop

from ubuntuone.platform.linux.os_helper import (
    access,
    allow_writes,
    listdir,
    make_dir,
    open_file,
    path_exists,
    remove_dir,
    remove_file,
    rename,
    set_dir_readonly,
    set_dir_readwrite,
    set_file_readonly,
    set_file_readwrite,
    stat_path,
)
from ubuntuone.platform.linux.vm_helper import (create_shares_link,
    get_udf_path_name, get_udf_path, get_share_path, VMMetadataUpgraderMixIn)
from ubuntuone.platform.linux import tools, event_logging
from filesystem_notifications import FilesystemMonitor


class ExternalInterface(object):
    """An ExternalInterface implemented with a DBus interface."""

    def __init__(self, main, glib_loop=False, broadcast_events=False,
                 dbus_iface=None):
        # avoid circular dependencies

        if dbus_iface is None:
            from ubuntuone.platform.linux import dbus_interface
            if not glib_loop:
                self.bus = dbus.SessionBus()
            else:
                loop = DBusGMainLoop(set_as_default=True)
                self.bus = dbus.SessionBus(loop)

            self.dbus_iface = dbus_interface.DBusInterface(
                self.bus, main, send_events=broadcast_events)

        else:
            self.dbus_iface = dbus_iface
            self.bus = None

    def _get_credentials(self):
        return self.dbus_iface.oauth_credentials

    def _set_credentials(self, credentials):
        self.dbus_iface.oauth_credentials = credentials

    oauth_credentials = property(fget=_get_credentials, fset=_set_credentials)

    def shutdown(self, with_restart):
        self.dbus_iface.shutdown(with_restart)

    def connect(self, *args, **kwargs):
        self.dbus_iface.connect(*args, **kwargs)
