# ubuntuone.syncdaemon.platform.messaging - Messages to the user
#
# Author: Eric Casteleijn <eric.casteleijn@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Module that implements sending messages to the end user."""

# TODO: We may want to enable different messaging systems. When none
# of them are available, we should fall back to silently discarding
# messages.

from time import time

try:
    import indicate
    USE_INDICATE = True
except ImportError:
    USE_INDICATE = False


from ubuntuone.status.messaging import AbstractMessaging

APPLICATION_NAME = 'Ubuntu One Client'


class Messaging(AbstractMessaging):
    """Notification of the end user."""

    def __init__(self, server_callback=None):  # pylint: disable=W0231
        if USE_INDICATE:
            self.indicators = {}
            self.server = indicate.indicate_server_ref_default()
            if server_callback is not None:
                self.server.connect("server-display", server_callback)
            self.server.set_type("message.u1")
            self.server.set_desktop_file(
                "/usr/share/applications/ubuntuone-control-panel-gtk.desktop")

    def show_message(self, sender, callback, message_time=None,
                     message_count=None, icon=None):
        """Show a message in the messaging menu."""
        if USE_INDICATE:
            indicator = self.indicators[sender] = indicate.Indicator()
            indicator.set_property("subtype", "u1")
            indicator.set_property("name", sender)
            indicator.set_property("sender", sender)
            indicator.connect("user-display", callback)

            if icon is not None:
                indicator.set_property_icon("icon", icon)
            if message_count is not None:
                indicator.set_property("count", str(message_count))
            else:
                if message_time is None:
                    message_time = time()
                indicator.set_property_time("time", message_time)
            indicator.set_property("draw-attention", "true")
            self.server.show()
            indicator.show()
            return indicator

    def update_count(self, sender, new_count):
        """Update the count for an existing indicator."""
        self.indicators[sender].set_property("count", str(new_count))


def hide_message(indicator):
    """Remove the message once it has been dealt with."""
    if USE_INDICATE:
        indicator.set_property("draw-attention", "false")
        indicator.hide()
