# ubuntuone.platform.linux - linux platform imports
#
# Author: Lucio Torre <lucio.torre@canonical.com>
#
# Copyright 2009 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Linux import for ubuntuone-client

This module has to have all linux specific modules and provide the api required
to support the linux platform.
"""

import os
import stat

from contextlib import contextmanager

platform = "linux2"


def set_file_readonly(path):
    """Change path permissions to readonly in a file."""
    os.chmod(path, 0444)

def set_file_readwrite(path):
    """Change path permissions to readwrite in a file."""
    os.chmod(path, 0774)

def set_dir_readonly(path):
    """Change path permissions to readonly in a dir."""
    os.chmod(path, 0555)

def set_dir_readwrite(path):
    """Change path permissions to readwrite in a dir."""
    os.chmod(path, 0775)

@contextmanager
def allow_writes(path):
    """A very simple context manager to allow writting in RO dirs."""
    prev_mod = stat.S_IMODE(os.stat(path).st_mode)
    os.chmod(path, 0755)
    yield
    os.chmod(path, prev_mod)

def remove_file(path):
    """Remove a file."""
    os.remove(path)

def remove_dir(path):
    """Remove a dir."""
    os.rmdir(path)

def path_exists(path):
    """Return if the path exists."""
    return os.path.exists(path)

def make_dir(path, recursive=False):
    """Make a dir, optionally creating all the middle ones."""
    if recursive:
        os.makedirs(path)
    else:
        os.mkdir(path)

def open_file(path, mode='r'):
    """Open a file."""
    return open(path, mode)

def rename(path_from, path_to):
    """Rename a file or directory."""
    os.rename(path_from, path_to)

def listdir(directory):
    """List a directory."""
    return os.listdir(directory)

def access(path):
    """Return if the path is at least readable."""
    return os.access(path, os.R_OK)

def stat_path(path):
    """Return stat info about a path."""
    return os.lstat(path)

