# ubuntuone.syncdaemon.status_listener
#
# Author: Alejandro J. Cura <alecu@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Listener for event queue that updates the UI to show syncdaemon status."""

from ubuntuone.status.aggregator import StatusFrontend
from ubuntuone.syncdaemon import action_queue

def should_start_listener():
    """Check if the status listener should be started."""
    # TODO: look this up in some configuration object
    return True

def get_listener(fsm, vm):
    """Return an instance of the status listener, or None if turned off."""
    if should_start_listener():
        status_frontend = StatusFrontend()
        return StatusListener(fsm, vm, status_frontend)
    else:
        return None

#TODO: hookup the shutdown of the listener to the cleanup in the aggregator
class StatusListener(object):
    """SD listener for EQ events that turns them into status updates."""

    def __init__(self, fsm, vm, status_frontend):
        """Initialize this instance with the FSM and VM."""
        self.fsm = fsm
        self.vm = vm
        self.status_frontend = status_frontend

    def handle_AQ_CHANGE_PUBLIC_ACCESS_OK(self, share_id, node_id, is_public,
                                                  public_url):
        """The status of a published resource changed."""
        if is_public:
            self.status_frontend.file_published(public_url)
        else:
            self.status_frontend.file_unpublished(public_url)

    def handle_SYS_QUEUE_ADDED(self, command):
        """A command has been added to the queue."""
        if isinstance(command, action_queue.Download):
            self.status_frontend.download_started(command)
        elif isinstance(command, action_queue.Upload):
            self.status_frontend.upload_started(command)
        else:
            self.status_frontend.queue_added(command)

    def handle_SYS_QUEUE_REMOVED(self, command):
        """A command has been removed from the queue."""
        if isinstance(command, action_queue.Download):
            self.status_frontend.download_finished(command)
        elif isinstance(command, action_queue.Upload):
            self.status_frontend.upload_finished(command)
        else:
            self.status_frontend.queue_removed(command)

    def handle_SYS_QUEUE_DONE(self):
        """The queue has finished processing everything."""
        self.status_frontend.queue_done()

    def handle_VM_SHARE_CREATED(self, share_id):
        """A new share is available for subscription."""
        share = self.vm.get_volume(share_id)
        self.status_frontend.new_share_available(share)

    def handle_VM_UDF_CREATED(self, udf):
        """A new udf is available for subscription."""
        self.status_frontend.new_udf_available(udf)
